@@ -61,6 +61,7 @@ class SortOrder(PathFeature):
         return self.path + " " + self.order
     def to_string(self):
         return str(self)
+
 class SortOrderList(object):
     def __init__(self, *sos):
         self.sort_orders = []
@@ -83,6 +84,8 @@ class SortOrderList(object):
         self.sort_orders = []
     def is_empty(self):
         return len(self.sort_orders) == 0
+    def __len__(self):
+        return len(self.sort_orders)
     def next(self):
         return self.sort_orders.next()
     def __iter__(self):
